import { Injectable } from '@angular/core';

import { WebSocketService } from './websocket.service';
import { ProcessCommand } from './processcommand';
import { filter } from 'rxjs/operators';


@Injectable()
export class ProcessManagerService {
  key = 'processmanager';
  process_name: string;

  constructor(private webSocketService: WebSocketService) {}

  init() {
    this.webSocketService.connect();
  }

  subscribeCallback(process_name: string, callback: (event: any) => void) {
    this.webSocketService.observeKey<ProcessCommand>(this.key)
      .pipe(filter(message => message.data.process_name === process_name)).subscribe(callback);
  }

  sendCommand(command: string, process_name: string, callback?: (event: any) => void) {
    if (callback) {
      this.subscribeCallback(process_name, callback);
    }
    this.webSocketService.send(this.key, {'command': command, 'process_name': process_name});
  }

  startProcess(process_name: string, callback?: (event: any) => void) {
    this.sendCommand('start', process_name, callback);
  }

  stopProcess(process_name: string, callback?: (event: any) => void) {
    this.sendCommand('stop', process_name, callback);
  }

  restartProcess(process_name: string, callback?: (event: any) => void) {
    this.sendCommand('restart', process_name, callback);
  }
}
